.. module:: archimedes

.. _reference:

################
📚 API Reference
################

This reference provides a detailed overview of the functions and classes in the
Archimedes library.

Modules
==============

.. autosummary::
    :toctree: ../generated/api
    :template: module.rst

    observers
    optimize
    sysid
    tree
    tree.struct


Core Functions
==============

.. autosummary::
    :toctree: ../generated/api
    :template: base.rst

    array
    codegen
    discretize
    sym
    sym_like
    zeros
    ones
    zeros_like
    ones_like
    eye
    scan
    switch
    vmap
    compile
    callback
    grad
    jac
    hess
    jvp
    vjp
    interpolant
    integrator
    odeint
    nlp_solver
    minimize
    implicit
    root
    qpsol

